@@ -1,13 +1,13 @@
 #' @title Check if a path is suited for creating an output file
 #'
 #' @description
-#' Check if a file path can be safely be used to create a file and write to it.
+#' Check if a file path can be used safely to create a file and write to it.
 #'
 #' This is checked:
 #' \itemize{
 #'  \item{Does \code{dirname(x)} exist?}
 #'  \item{Does no file under path \code{x} exist?}
-#'  \item{Is \code{dirname(x)} writeable?}
+#'  \item{Is \code{dirname(x)} writable?}
 #' }
 #' Paths are relative to the current working directory.
 #'
@@ -15,15 +15,17 @@
 #' @template x
 #' @param overwrite [\code{logical(1)}]\cr
 #'  If \code{TRUE}, an existing file in place is allowed if it
-#'  it is both readable and writeable.
+#'  it is both readable and writable.
 #'  Default is \code{FALSE}.
+#' @param extension [\code{character(1)}]\cr
+#'  Extension of the file, e.g. \dQuote{txt} or \dQuote{tar.gz}.
 #' @template checker
 #' @family filesystem
 #' @export
 #' @examples
 #' # Can we create a file in the tempdir?
 #' testPathForOutput(file.path(tempdir(), "process.log"))
-checkPathForOutput = function(x, overwrite = FALSE) {
+checkPathForOutput = function(x, overwrite = FALSE, extension = NULL) {
   if (!qtest(x, "S+"))
     return("No path provided")
   qassert(overwrite, "B1")
@@ -41,6 +43,12 @@ checkPathForOutput = function(x, overwrite = FALSE) {
       return(checkAccess(dn, "w") %and% checkAccess(x[w], "rw"))
     return(sprintf("File at path already exists: '%s'", x[w]))
   }
+
+  if (!is.null(extension)) {
+    qassert(extension, "S1")
+    if (!endsWith(x, paste0(".", extension)))
+      return(sprintf("File must have extension '.%s'", extension))
+  }
   return(checkAccess(dn, "w"))
 }
 
@@ -52,7 +60,7 @@ check_path_for_output = checkPathForOutput
 #' @include makeAssertion.R
 #' @template assert
 #' @rdname checkPathForOutput
-assertPathForOutput = makeAssertionFunction(checkPathForOutput)
+assertPathForOutput = makeAssertionFunction(checkPathForOutput, use.namespace = FALSE)
 
 #' @export
 #' @rdname checkPathForOutput
@@ -71,4 +79,4 @@ test_path_for_output = testPathForOutput
 #' @include makeExpectation.R
 #' @template expect
 #' @rdname checkPathForOutput
-expect_path_for_output = makeExpectationFunction(checkPathForOutput)
+expect_path_for_output = makeExpectationFunction(checkPathForOutput, use.namespace = FALSE)
